<?php
declare (strict_types = 1);
namespace App\Controller;

use App\Constants\ErrorCode;
use App\JsonRpc\NewsServiceInterface;
use App\JsonRpc\WebsiteServiceInterface;
use App\Tools\Result;
use Hyperf\Context\Context;
use Hyperf\Di\Annotation\Inject;
use Hyperf\Validation\Contract\ValidatorFactoryInterface;

/**
 * Class WebController
 * @package App\Controller
 */
class WebController extends AbstractController
{
    #[Inject]
    protected ValidatorFactoryInterface $validationFactory;
    private $publicServiceClient;
    /**
     * @var NewsServiceInterface
     */
    #[Inject]
    private $newsServiceClient;

    /**
     * @var WebsiteServiceInterface
     */
    #[Inject]
    private $websiteServiceClient;

    /**
     * 获取栏目导航
     * @return array
     */
    public function getWebsiteCategory()
    {

        $requireData = $this->request->all();
        $data = [
            'website_id' => Context::get("SiteId"),
            'pageSize' => $requireData['pageSize'],
        ];
        // var_dump("网站id：",Context::get("SiteId"));
        $result = $this->websiteServiceClient->getWebsiteCategory($data);
        if ($result['code'] != ErrorCode::SUCCESS) {
            return Result::error($result['message'], 0, []);
        }
        return Result::success($result['data']);
    }

}
